==> jgit_3.3.1.orig.tar.xz: jgit-3.3.1/org.eclipse.jgit.test/tst/org/eclipse/jgit/revwalk/RevWalkShallowTest.java <==
/*
 * Copyright (C) 2012, Marc Strapetz <marc.strapetz@syntevo.com>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.revwalk;

import java.io.File;
import java.io.IOException;

import org.eclipse.jgit.junit.JGitTestUtil;
import org.eclipse.jgit.lib.*;
import org.junit.*;

import static org.junit.Assert.*;

public class RevWalkShallowTest extends RevWalkTestCase {

	// Accessing ==============================================================

	@Test
	public void testDepth1() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(c);

		createShallowFile(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testDepth2() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(c);

		createShallowFile(c);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertCommit(c, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testDepth3() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(c);

		createShallowFile(b);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertCommit(c, rw.next());
		assertCommit(b, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testMergeCommitOneParentShallow() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(b);
		final RevCommit e = commit(d);
		final RevCommit merge = commit(c, e);

		createShallowFile(e);

		rw.reset();
		markStart(merge);
		assertCommit(merge, rw.next());
		assertCommit(e, rw.next());
		assertCommit(c, rw.next());
		assertCommit(b, rw.next());
		assertCommit(a, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testMergeCommitEntirelyShallow() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(b);
		final RevCommit e = commit(d);
		final RevCommit merge = commit(c, e);

		createShallowFile(c, e);

		rw.reset();
		markStart(merge);
		assertCommit(merge, rw.next());
		assertCommit(e, rw.next());
		assertCommit(c, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testObjectDirectorySnapshot() throws Exception {
		RevCommit a = commit();
		RevCommit b = commit(a);
		RevCommit c = commit(b);
		RevCommit d = commit(c);

		createShallowFile(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertNull(rw.next());

		rw = createRevWalk();
		a = rw.lookupCommit(a);
		b = rw.lookupCommit(b);
		c = rw.lookupCommit(c);
		d = rw.lookupCommit(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertNull(rw.next());

		createShallowFile(c);

		rw = createRevWalk();
		a = rw.lookupCommit(a);
		b = rw.lookupCommit(b);
		c = rw.lookupCommit(c);
		d = rw.lookupCommit(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertCommit(c, rw.next());
		assertNull(rw.next());
	}

	private void createShallowFile(ObjectId... shallowCommits)
			throws IOException {
		final StringBuilder builder = new StringBuilder();
		for (ObjectId commit : shallowCommits)
			builder.append(commit.getName() + "\n");
		JGitTestUtil.write(new File(db.getDirectory(), "shallow"),
				builder.toString());
	}
}

==> jgit_4.11.9.orig.tar.xz: jgit-4.11.9.201909030838-r/org.eclipse.jgit.test/tst/org/eclipse/jgit/revwalk/RevWalkShallowTest.java <==
/*
 * Copyright (C) 2012, Marc Strapetz <marc.strapetz@syntevo.com>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.revwalk;

import static org.junit.Assert.assertNull;

import java.io.File;
import java.io.IOException;

import org.eclipse.jgit.junit.JGitTestUtil;
import org.eclipse.jgit.lib.ObjectId;
import org.junit.Test;

public class RevWalkShallowTest extends RevWalkTestCase {

	// Accessing ==============================================================

	@Test
	public void testDepth1() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(c);

		createShallowFile(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testDepth2() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(c);

		createShallowFile(c);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertCommit(c, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testDepth3() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(c);

		createShallowFile(b);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertCommit(c, rw.next());
		assertCommit(b, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testMergeCommitOneParentShallow() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(b);
		final RevCommit e = commit(d);
		final RevCommit merge = commit(c, e);

		createShallowFile(e);

		rw.reset();
		markStart(merge);
		assertCommit(merge, rw.next());
		assertCommit(e, rw.next());
		assertCommit(c, rw.next());
		assertCommit(b, rw.next());
		assertCommit(a, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testMergeCommitEntirelyShallow() throws Exception {
		final RevCommit a = commit();
		final RevCommit b = commit(a);
		final RevCommit c = commit(b);
		final RevCommit d = commit(b);
		final RevCommit e = commit(d);
		final RevCommit merge = commit(c, e);

		createShallowFile(c, e);

		rw.reset();
		markStart(merge);
		assertCommit(merge, rw.next());
		assertCommit(e, rw.next());
		assertCommit(c, rw.next());
		assertNull(rw.next());
	}

	@Test
	public void testObjectDirectorySnapshot() throws Exception {
		RevCommit a = commit();
		RevCommit b = commit(a);
		RevCommit c = commit(b);
		RevCommit d = commit(c);

		createShallowFile(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertNull(rw.next());

		rw = createRevWalk();
		a = rw.lookupCommit(a);
		b = rw.lookupCommit(b);
		c = rw.lookupCommit(c);
		d = rw.lookupCommit(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertNull(rw.next());

		createShallowFile(c);

		rw = createRevWalk();
		a = rw.lookupCommit(a);
		b = rw.lookupCommit(b);
		c = rw.lookupCommit(c);
		d = rw.lookupCommit(d);

		rw.reset();
		markStart(d);
		assertCommit(d, rw.next());
		assertCommit(c, rw.next());
		assertNull(rw.next());
	}

	private void createShallowFile(ObjectId... shallowCommits)
			throws IOException {
		final StringBuilder builder = new StringBuilder();
		for (ObjectId commit : shallowCommits)
			builder.append(commit.getName() + "\n");
		JGitTestUtil.write(new File(db.getDirectory(), "shallow"),
				builder.toString());
	}
}
